diff --git a/src/main/java/org/orekit/rugged/linesensor/LineSensor.java b/src/main/java/org/orekit/rugged/linesensor/LineSensor.java
index bd1d9155afdee3fb55252c4a0442ed255644a5c6..88dfef651f082b4780ea72e920986b8d5d66d35c 100644
--- a/src/main/java/org/orekit/rugged/linesensor/LineSensor.java
+++ b/src/main/java/org/orekit/rugged/linesensor/LineSensor.java
@@ -16,8 +16,6 @@
  */
 package org.orekit.rugged.linesensor;
 
-import java.util.List;
-
 import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;
 import org.orekit.rugged.los.TimeDependentLOS;
 import org.orekit.time.AbsoluteDate;
@@ -40,7 +38,7 @@ public class LineSensor {
     private final Vector3D position;
 
     /** Pixels lines-of-sight. */
-    private final List<TimeDependentLOS> los;
+    private final TimeDependentLOS los;
 
     /** Simple constructor.
      * @param name name of the sensor
@@ -49,7 +47,7 @@ public class LineSensor {
      * @param datationModel datation model
      */
     public LineSensor(final String name, final LineDatation datationModel,
-                      final Vector3D position, final List<TimeDependentLOS> los) {
+                      final Vector3D position, final TimeDependentLOS los) {
 
         this.name          = name;
         this.datationModel = datationModel;
@@ -69,7 +67,7 @@ public class LineSensor {
      * @return number of pixels
      */
     public int getNbPixels() {
-        return los.size();
+        return los.getNbPixels();
     }
 
     /** Get the pixel normalized line-of-sight at some date.
@@ -78,7 +76,7 @@ public class LineSensor {
      * @return pixel normalized line-of-sight
      */
     public Vector3D getLos(final AbsoluteDate date, final int i) {
-        return los.get(i).getLOS(date).normalize();
+        return los.getLOS(i, date);
     }
 
     /** Get the date.
diff --git a/src/main/java/org/orekit/rugged/los/LOSBuilder.java b/src/main/java/org/orekit/rugged/los/LOSBuilder.java
index 581ffb8bc1fc839f420150999caac66f6c1eb2b1..bca6f670ba67b675e0b1b862196cf65fd24029e8 100644
--- a/src/main/java/org/orekit/rugged/los/LOSBuilder.java
+++ b/src/main/java/org/orekit/rugged/los/LOSBuilder.java
@@ -41,12 +41,23 @@ public class LOSBuilder {
     /** Transforms to be applied. */
     private final List<LOSTransform> transforms;
 
+    /** Flag for time-independent only transforms. */
+    private boolean timeIndependent;
+
     /** Create builder.
      * @param rawLOS raw fixed lines-of-sight
      */
     public LOSBuilder(final List<Vector3D> rawLOS) {
-        this.rawLOS = rawLOS;
-        this.transforms = new ArrayList<LOSTransform>();
+        this.rawLOS          = rawLOS;
+        this.transforms      = new ArrayList<LOSTransform>();
+        this.timeIndependent = true;
+    }
+
+    /** Add a transform to be applied after the already registered transforms.
+     * @param transform transform to be applied to the lines-of-sight
+     */
+    public void addTransform(final TimeIndependentLOSTransform transform) {
+        transforms.add(new TransformConverter(transform));
     }
 
     /** Add a transform to be applied after the already registered transforms.
@@ -54,57 +65,135 @@ public class LOSBuilder {
      */
     public void addTransform(final LOSTransform transform) {
         transforms.add(transform);
+        timeIndependent = false;
     }
 
     /** Build a list of transformed lines-of-sight.
      * @return list of transformed lines of sight
      */
-    public List<TimeDependentLOS> build() {
-
-        // copy the current transforms set, to ensure immutability
-        // of the built list, in case addTransform is called again after build
-        final List<LOSTransform> copy = new ArrayList<LOSTransform>(transforms);
-        final List<TimeDependentLOS> transformed = new ArrayList<TimeDependentLOS>(rawLOS.size());
-        for (int i = 0; i < rawLOS.size(); ++i) {
-            transformed.add(new TransformsSequenceLOS(i, rawLOS.get(i), copy));
+    public TimeDependentLOS build() {
+
+        if (timeIndependent) {
+            // fast implementation for time-independent lines-of-sight
+            return new FixedLOS(rawLOS, transforms);
+        } else {
+            // regular implementation, for time-dependent lines-of-sight
+            return new TransformsSequenceLOS(rawLOS, transforms);
         }
 
-        return transformed;
+    }
+
+    /** Converter from time-independent transform to time-dependent transform. */
+    private static class TransformConverter implements LOSTransform {
+
+        /** Underlying transform. */
+        private final TimeIndependentLOSTransform transform;
+
+        /** Simple constructor.
+         * @param transform underlying time-independent transform
+         */
+        public TransformConverter(final TimeIndependentLOSTransform transform) {
+            this.transform = transform;
+        }
+
+        /** Get the underlying transform.
+         * @return underlying time-independent transform
+         */
+        public TimeIndependentLOSTransform getTransform() {
+            return transform;
+        }
+
+        /** {@inheritDoc} */
+        @Override
+        public Vector3D transformLOS(final int i, final Vector3D los, final AbsoluteDate date) {
+            return transform.transformLOS(i, los);
+        }
 
     }
 
-    /** Implement time-dependent LOS by applying all registered transforms. */
-    private static class TransformsSequenceLOS implements TimeDependentLOS {
+    /** Implement time-independent LOS by applying all registered transforms at construction. */
+    private static class FixedLOS implements TimeDependentLOS {
+
+        /** Fixed direction for los. */
+        private final Vector3D[]  los;
+
+        /** Simple constructor.
+         * @param raw raw direction
+         * @param transforms transforms to apply (must be time-independent!)
+         */
+        public FixedLOS(final List<Vector3D> raw, final List<LOSTransform> transforms) {
+
+            los = new Vector3D[raw.size()];
+
+            // apply transforms only once
+            for (int i = 0; i < raw.size(); ++i) {
+                Vector3D v = raw.get(i);
+                for (final LOSTransform transform : transforms) {
+                    v = ((TransformConverter) transform).getTransform().transformLOS(i, v);
+                }
+                los[i] = v.normalize();
+            }
 
-        /** LOS index. */
-        private final int index;
+        }
+
+        /** {@inheritDoc} */
+        public int getNbPixels() {
+            return los.length;
+        }
+
+        /** {@inheritDoc} */
+        public Vector3D getLOS(final int index, final AbsoluteDate date) {
+            return los[index];
+        }
+
+    }
+
+    /** Implement time-dependent LOS by applying all registered transforms at runtime. */
+    private static class TransformsSequenceLOS implements TimeDependentLOS {
 
         /** Raw direction. */
-        private final Vector3D raw;
+        private final Vector3D[] raw;
 
         /** Transforms to be applied. */
-        private final List<LOSTransform> transforms;
+        private final LOSTransform[] transforms;
 
         /** Simple constructor.
-         * @param index los index
          * @param raw raw direction
          * @param transforms transforms to apply
          */
-        public TransformsSequenceLOS(final int index, final Vector3D raw, final List<LOSTransform> transforms) {
-            this.index      = index;
-            this.raw        = raw;
-            this.transforms = transforms;
+        public TransformsSequenceLOS(final List<Vector3D> raw, final List<LOSTransform> transforms) {
+
+            // copy the lists, to ensure immutability of the built object,
+            // in case addTransform is called again after build
+            // or the raw LOS list is changed by caller
+
+            this.raw = new Vector3D[raw.size()];
+            for (int i = 0; i < raw.size(); ++i) {
+                this.raw[i] = raw.get(i);
+            }
+
+            this.transforms = new LOSTransform[transforms.size()];
+            for (int i = 0; i < transforms.size(); ++i) {
+                this.transforms[i] = transforms.get(i);
+            }
+
+        }
+
+        /** {@inheritDoc} */
+        public int getNbPixels() {
+            return raw.length;
         }
 
         /** {@inheritDoc} */
         @Override
-        public Vector3D getLOS(final AbsoluteDate date) {
-            Vector3D los = raw;
+        public Vector3D getLOS(final int index, final AbsoluteDate date) {
+            Vector3D los = raw[index];
             for (final LOSTransform transform : transforms) {
                 los = transform.transformLOS(index, los, date);
             }
             return los.normalize();
         }
+
     }
 
 }
diff --git a/src/main/java/org/orekit/rugged/los/LOSTransform.java b/src/main/java/org/orekit/rugged/los/LOSTransform.java
index a6f10ccf633d4f960840106a62e6be9ba2aa240f..ff085f729a9829b31c51ffed7c65b365b3425b7e 100644
--- a/src/main/java/org/orekit/rugged/los/LOSTransform.java
+++ b/src/main/java/org/orekit/rugged/los/LOSTransform.java
@@ -24,6 +24,7 @@ import org.orekit.time.AbsoluteDate;
  * @see LOSBuilder
  */
 interface LOSTransform {
+
     /** Transform a line-of-sight.
      * @param i los pixel index
      * @param los line-of-sight to transform
@@ -31,4 +32,5 @@ interface LOSTransform {
      * @return transformed line-of-sight
      */
     Vector3D transformLOS(int i, Vector3D los, AbsoluteDate date);
+
 }
diff --git a/src/main/java/org/orekit/rugged/los/TimeDependentLOS.java b/src/main/java/org/orekit/rugged/los/TimeDependentLOS.java
index 9effc6b0c70568fbbc08c0300216c827b6429cd8..159c991b375c10b3171c189ca630c2d99cba518b 100644
--- a/src/main/java/org/orekit/rugged/los/TimeDependentLOS.java
+++ b/src/main/java/org/orekit/rugged/los/TimeDependentLOS.java
@@ -25,10 +25,16 @@ import org.orekit.time.AbsoluteDate;
  */
 public interface TimeDependentLOS {
 
+    /** Get the number of pixels.
+     * @return number of pixels
+     */
+    int getNbPixels();
+
     /** Get the line of sight for a given date.
+     * @param index los pixel index
      * @param date date
      * @return line of sight
      */
-    Vector3D getLOS(AbsoluteDate date);
+    Vector3D getLOS(int index, AbsoluteDate date);
 
 }
diff --git a/src/test/java/org/orekit/rugged/api/RuggedBuilderTest.java b/src/test/java/org/orekit/rugged/api/RuggedBuilderTest.java
index 0fa8263fd464203f0ebef815f10d56fc02f2bc7a..fb8fc18ea6d5bdc370cca3f6a50e7dbc85d5ae2b 100644
--- a/src/test/java/org/orekit/rugged/api/RuggedBuilderTest.java
+++ b/src/test/java/org/orekit/rugged/api/RuggedBuilderTest.java
@@ -341,9 +341,9 @@ public class RuggedBuilderTest {
         // position: 1.5m in front (+X) and 20 cm above (-Z) of the S/C center of mass
         // los: swath in the (YZ) plane, looking at 50° roll, ±1° aperture
         Vector3D position = new Vector3D(1.5, 0, -0.2);
-        List<TimeDependentLOS> los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
-                                                                       FastMath.toRadians(50.0)).applyTo(Vector3D.PLUS_K),
-                                                          Vector3D.PLUS_I, FastMath.toRadians(1.0), dimension);
+        TimeDependentLOS los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
+                                                                 FastMath.toRadians(50.0)).applyTo(Vector3D.PLUS_K),
+                                                    Vector3D.PLUS_I, FastMath.toRadians(1.0), dimension);
 
         // linear datation model: at reference time we get line 100, and the rate is one line every 1.5ms
         LineDatation lineDatation = new LinearLineDatation(crossing, dimension / 2, 1.0 / 1.5e-3);
@@ -409,9 +409,9 @@ public class RuggedBuilderTest {
         // position: 1.5m in front (+X) and 20 cm above (-Z) of the S/C center of mass
         // los: swath in the (YZ) plane, looking at 50° roll, ±1° aperture
         Vector3D position = new Vector3D(1.5, 0, -0.2);
-        List<TimeDependentLOS> los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
-                                                                       FastMath.toRadians(50.0)).applyTo(Vector3D.PLUS_K),
-                                                          Vector3D.PLUS_I, FastMath.toRadians(1.0), dimension);
+        TimeDependentLOS los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
+                                                                 FastMath.toRadians(50.0)).applyTo(Vector3D.PLUS_K),
+                                                    Vector3D.PLUS_I, FastMath.toRadians(1.0), dimension);
 
         // linear datation model: at reference time we get line 100, and the rate is one line every 1.5ms
         LineDatation lineDatation = new LinearLineDatation(crossing, dimension / 2, 1.0 / 1.5e-3);
@@ -458,9 +458,9 @@ public class RuggedBuilderTest {
         // position: 1.5m in front (+X) and 20 cm above (-Z) of the S/C center of mass
         // los: swath in the (YZ) plane, looking at 50° roll, ±1° aperture
         Vector3D position = new Vector3D(1.5, 0, -0.2);
-        List<TimeDependentLOS> los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
-                                                                       FastMath.toRadians(50.0)).applyTo(Vector3D.PLUS_K),
-                                                          Vector3D.PLUS_I, FastMath.toRadians(1.0), dimension);
+        TimeDependentLOS los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
+                                                                 FastMath.toRadians(50.0)).applyTo(Vector3D.PLUS_K),
+                                                    Vector3D.PLUS_I, FastMath.toRadians(1.0), dimension);
 
         // linear datation model: at reference time we get line 100, and the rate is one line every 1.5ms
         LineDatation lineDatation = new LinearLineDatation(crossing, dimension / 2, 1.0 / 1.5e-3);
@@ -662,7 +662,7 @@ public class RuggedBuilderTest {
 
     }
 
-    private List<TimeDependentLOS> createLOSPerfectLine(Vector3D center, Vector3D normal, double halfAperture, int n) {
+    private TimeDependentLOS createLOSPerfectLine(Vector3D center, Vector3D normal, double halfAperture, int n) {
         List<Vector3D> list = new ArrayList<Vector3D>(n);
         for (int i = 0; i < n; ++i) {
             double alpha = (halfAperture * (2 * i + 1 - n)) / (n - 1);
diff --git a/src/test/java/org/orekit/rugged/api/RuggedTest.java b/src/test/java/org/orekit/rugged/api/RuggedTest.java
index d493f4ac53c61896eedeb683b4c0d04b5f3005d3..0ffe6a8144b54354c4ad9ba325f2aab4d179abb6 100644
--- a/src/test/java/org/orekit/rugged/api/RuggedTest.java
+++ b/src/test/java/org/orekit/rugged/api/RuggedTest.java
@@ -94,7 +94,6 @@ public class RuggedTest {
 
     // the following test is disabled by default
     // it is only used to check timings, and also creates a large (66M) temporary file
-    @Ignore
     @Test
     public void testMayonVolcanoTiming()
         throws RuggedException, OrekitException, URISyntaxException {
@@ -121,8 +120,8 @@ public class RuggedTest {
         // position: 1.5m in front (+X) and 20 cm above (-Z) of the S/C center of mass
         // los: swath in the (YZ) plane, centered at +Z, ±10° aperture, 960 pixels
         Vector3D position = new Vector3D(1.5, 0, -0.2);
-        List<TimeDependentLOS> los = createLOSPerfectLine(Vector3D.PLUS_K, Vector3D.PLUS_I,
-                                                          FastMath.toRadians(10.0), dimension);
+        TimeDependentLOS los = createLOSPerfectLine(Vector3D.PLUS_K, Vector3D.PLUS_I,
+                                                    FastMath.toRadians(10.0), dimension);
 
         // linear datation model: at reference time we get line 1000, and the rate is one line every 1.5ms
         LineDatation lineDatation = new LinearLineDatation(crossing, dimension / 2, 1.0 / 1.5e-3);
@@ -149,7 +148,7 @@ public class RuggedTest {
 
         try {
 
-            int              size   = (lastLine - firstLine) * los.size() * 3 * Integer.SIZE / 8;
+            int              size   = (lastLine - firstLine) * los.getNbPixels() * 3 * Integer.SIZE / 8;
             RandomAccessFile out    = new RandomAccessFile(tempFolder.newFile(), "rw");
             MappedByteBuffer buffer = out.getChannel().map(FileChannel.MapMode.READ_WRITE, 0, size);
 
@@ -165,7 +164,7 @@ public class RuggedTest {
                     buffer.putInt(lonCode);
                     buffer.putInt(altCode);
                 }
-                pixels += los.size();
+                pixels += los.getNbPixels();
                 if  (line % 100 == 0) {
                     System.out.format(Locale.US, "%5.0f%n", line);
                 }
@@ -177,7 +176,7 @@ public class RuggedTest {
                               "%n%n%5dx%5d:%n" +
                               "  Orekit initialization and DEM creation   : %5.1fs%n" +
                               "  direct location and %3dM grid writing: %5.1fs (%.1f px/s)%n",
-                              lastLine - firstLine, los.size(),
+                              lastLine - firstLine, los.getNbPixels(),
                               1.0e-3 *(t1 - t0), sizeM, 1.0e-3 *(t2 - t1), pixels / (1.0e-3 * (t2 - t1)));
         } catch (IOException ioe) {
             Assert.fail(ioe.getLocalizedMessage());
@@ -202,8 +201,8 @@ public class RuggedTest {
         // position: 1.5m in front (+X) and 20 cm above (-Z) of the S/C center of mass
         // los: swath in the (YZ) plane, centered at +Z, ±10° aperture, 960 pixels
         Vector3D position = new Vector3D(1.5, 0, -0.2);
-        List<TimeDependentLOS> los = createLOSPerfectLine(Vector3D.PLUS_K, Vector3D.PLUS_I,
-                                                          FastMath.toRadians(10.0), dimension);
+        TimeDependentLOS los = createLOSPerfectLine(Vector3D.PLUS_K, Vector3D.PLUS_I,
+                                                    FastMath.toRadians(10.0), dimension);
 
         // linear datation model: at reference time we get line 200, and the rate is one line every 1.5ms
         LineDatation lineDatation = new LinearLineDatation(crossing, dimension / 2, 1.0 / 1.5e-3);
@@ -280,8 +279,8 @@ public class RuggedTest {
         // position: 1.5m in front (+X) and 20 cm above (-Z) of the S/C center of mass
         // los: swath in the (YZ) plane, centered at +Z, ±10° aperture, 960 pixels
         Vector3D position = new Vector3D(1.5, 0, -0.2);
-        List<TimeDependentLOS> los = createLOSPerfectLine(Vector3D.PLUS_K, Vector3D.PLUS_I,
-                                                          FastMath.toRadians(10.0), dimension);
+        TimeDependentLOS los = createLOSPerfectLine(Vector3D.PLUS_K, Vector3D.PLUS_I,
+                                                    FastMath.toRadians(10.0), dimension);
 
         // linear datation model: at reference time we get line 200, and the rate is one line every 1.5ms
         LineDatation lineDatation = new LinearLineDatation(crossing, dimension / 2, 1.0 / 1.5e-3);
@@ -338,9 +337,9 @@ public class RuggedTest {
         // position: 1.5m in front (+X) and 20 cm above (-Z) of the S/C center of mass
         // los: swath in the (YZ) plane, looking at 50° roll, ±1° aperture
         Vector3D position = new Vector3D(1.5, 0, -0.2);
-        List<TimeDependentLOS> los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
-                                                                       FastMath.toRadians(50.0)).applyTo(Vector3D.PLUS_K),
-                                                          Vector3D.PLUS_I, FastMath.toRadians(1.0), dimension);
+        TimeDependentLOS los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
+                                                                 FastMath.toRadians(50.0)).applyTo(Vector3D.PLUS_K),
+                                                    Vector3D.PLUS_I, FastMath.toRadians(1.0), dimension);
 
         // linear datation model: at reference time we get line 100, and the rate is one line every 1.5ms
         LineDatation lineDatation = new LinearLineDatation(crossing, dimension / 2, 1.0 / 1.5e-3);
@@ -399,9 +398,9 @@ public class RuggedTest {
         // position: 1.5m in front (+X) and 20 cm above (-Z) of the S/C center of mass
         // los: swath in the (YZ) plane, looking at 50° roll, ±1° aperture
         Vector3D position = new Vector3D(1.5, 0, -0.2);
-        List<TimeDependentLOS> los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
-                                                                       FastMath.toRadians(50.0)).applyTo(Vector3D.PLUS_K),
-                                                          Vector3D.PLUS_I, FastMath.toRadians(1.0), dimension);
+        TimeDependentLOS los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
+                                                                 FastMath.toRadians(50.0)).applyTo(Vector3D.PLUS_K),
+                                                    Vector3D.PLUS_I, FastMath.toRadians(1.0), dimension);
 
         // linear datation model: at reference time we get line 100, and the rate is one line every 1.5ms
         LineDatation lineDatation = new LinearLineDatation(crossing, dimension / 2, 1.0 / 1.5e-3);
@@ -456,9 +455,9 @@ public class RuggedTest {
         // position: 1.5m in front (+X) and 20 cm above (-Z) of the S/C center of mass
         // los: swath in the (YZ) plane, looking at 50° roll, ±1° aperture
         Vector3D position = new Vector3D(1.5, 0, -0.2);
-        List<TimeDependentLOS> los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
-                                                                       FastMath.toRadians(50.0)).applyTo(Vector3D.PLUS_K),
-                                                          Vector3D.PLUS_I, FastMath.toRadians(1.0), dimension);
+        TimeDependentLOS los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
+                                                                 FastMath.toRadians(50.0)).applyTo(Vector3D.PLUS_K),
+                                                    Vector3D.PLUS_I, FastMath.toRadians(1.0), dimension);
 
         // linear datation model: at reference time we get line 100, and the rate is one line every 1.5ms
         LineDatation lineDatation = new LinearLineDatation(crossing, dimension / 2, 1.0 / 1.5e-3);
@@ -516,9 +515,9 @@ public class RuggedTest {
         // position: 1.5m in front (+X) and 20 cm above (-Z) of the S/C center of mass
         // los: swath in the (YZ) plane, looking at 50° roll, ±1° aperture
         Vector3D position = new Vector3D(1.5, 0, -0.2);
-        List<TimeDependentLOS> los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
-                                                                       FastMath.toRadians(50.0)).applyTo(Vector3D.PLUS_K),
-                                                          Vector3D.PLUS_I, FastMath.toRadians(1.0), dimension);
+        TimeDependentLOS los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
+                                                                 FastMath.toRadians(50.0)).applyTo(Vector3D.PLUS_K),
+                                                    Vector3D.PLUS_I, FastMath.toRadians(1.0), dimension);
 
         // linear datation model: at reference time we get line 100, and the rate is one line every 1.5ms
         LineDatation lineDatation = new LinearLineDatation(crossing, dimension / 2, 1.0 / 1.5e-3);
@@ -560,7 +559,6 @@ public class RuggedTest {
 
     // the following test is disabled by default
     // it is only used to check timings, and also creates a large (38M) temporary file
-    @Ignore
     @Test
     public void testInverseLocationTiming()
         throws RuggedException, OrekitException, URISyntaxException {
@@ -582,9 +580,9 @@ public class RuggedTest {
             // position: 1.5m in front (+X) and 20 cm above (-Z) of the S/C center of mass
             // los: swath in the (YZ) plane, looking roughly at 50° roll (sensor-dependent), 2.6" per pixel
             Vector3D position = new Vector3D(1.5, 0, -0.2);
-            List<TimeDependentLOS> los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
-                                                                           FastMath.toRadians(50.0 - 0.001 * i)).applyTo(Vector3D.PLUS_K),
-                                                              Vector3D.PLUS_I, FastMath.toRadians(dimension * 2.6 / 3600.0), dimension);
+            TimeDependentLOS los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
+                                                                     FastMath.toRadians(50.0 - 0.001 * i)).applyTo(Vector3D.PLUS_K),
+                                                        Vector3D.PLUS_I, FastMath.toRadians(dimension * 2.6 / 3600.0), dimension);
 
             // linear datation model: at reference time we get roughly middle line, and the rate is one line every 1.5ms
             LineDatation lineDatation = new LinearLineDatation(crossing, i + dimension / 2, 1.0 / 1.5e-3);
@@ -934,10 +932,10 @@ public class RuggedTest {
         // position: 1.5m in front (+X) and 20 cm above (-Z) of the S/C center of mass
         // los: swath in the (YZ) plane, looking at nadir, 2.6" per pixel, 3" sagitta
         Vector3D position = new Vector3D(1.5, 0, -0.2);
-        List<TimeDependentLOS> los = createLOSCurvedLine(Vector3D.PLUS_K, Vector3D.PLUS_I,
-                                                         FastMath.toRadians(dimension * 2.6 / 3600.0),
-                                                         FastMath.toRadians(3.0 / 3600.0),
-                                                         dimension);
+        TimeDependentLOS los = createLOSCurvedLine(Vector3D.PLUS_K, Vector3D.PLUS_I,
+                                                   FastMath.toRadians(dimension * 2.6 / 3600.0),
+                                                   FastMath.toRadians(3.0 / 3600.0),
+                                                   dimension);
 
         // linear datation model: at reference time we get the middle line, and the rate is one line every 1.5ms
         LineDatation lineDatation = new LinearLineDatation(crossing, dimension / 2, 1.0 / 1.5e-3);
@@ -1013,10 +1011,10 @@ public class RuggedTest {
         // position: 1.5m in front (+X) and 20 cm above (-Z) of the S/C center of mass
         // los: swath in the (YZ) plane, looking at 50° roll, 2.6" per pixel
         Vector3D position = new Vector3D(1.5, 0, -0.2);
-        List<TimeDependentLOS> los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
-                                                                       FastMath.toRadians(50.0)).applyTo(Vector3D.PLUS_K),
-                                                          Vector3D.PLUS_I,
-                                                          FastMath.toRadians(dimension * 2.6 / 3600.0), dimension);
+        TimeDependentLOS los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
+                                                                 FastMath.toRadians(50.0)).applyTo(Vector3D.PLUS_K),
+                                                    Vector3D.PLUS_I,
+                                                    FastMath.toRadians(dimension * 2.6 / 3600.0), dimension);
 
         // linear datation model: at reference time we get the middle line, and the rate is one line every 1.5ms
         LineDatation lineDatation = new LinearLineDatation(crossing, dimension / 2, 1.0 / 1.5e-3);
@@ -1104,10 +1102,10 @@ public class RuggedTest {
         // position: 1.5m in front (+X) and 20 cm above (-Z) of the S/C center of mass
         // los: swath in the (YZ) plane, looking at 50° roll, 2.6" per pixel
         Vector3D position = new Vector3D(1.5, 0, -0.2);
-        List<TimeDependentLOS> los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
-                                                                       FastMath.toRadians(50.0)).applyTo(Vector3D.PLUS_K),
-                                                          Vector3D.PLUS_I,
-                                                          FastMath.toRadians(dimension * 2.6 / 3600.0), dimension);
+        TimeDependentLOS los = createLOSPerfectLine(new Rotation(Vector3D.PLUS_I,
+                                                                 FastMath.toRadians(50.0)).applyTo(Vector3D.PLUS_K),
+                                                    Vector3D.PLUS_I,
+                                                    FastMath.toRadians(dimension * 2.6 / 3600.0), dimension);
 
         // linear datation model: at reference time we get line 100, and the rate is one line every 1.5ms
         LineDatation lineDatation = new LinearLineDatation(crossing, dimension / 2, 1.0 / 1.5e-3);
@@ -1233,7 +1231,7 @@ public class RuggedTest {
 
     }
 
-    private List<TimeDependentLOS> createLOSPerfectLine(Vector3D center, Vector3D normal, double halfAperture, int n) {
+    private TimeDependentLOS createLOSPerfectLine(Vector3D center, Vector3D normal, double halfAperture, int n) {
         List<Vector3D> list = new ArrayList<Vector3D>(n);
         for (int i = 0; i < n; ++i) {
             double alpha = (halfAperture * (2 * i + 1 - n)) / (n - 1);
@@ -1242,8 +1240,8 @@ public class RuggedTest {
         return new LOSBuilder(list).build();
     }
 
-    private List<TimeDependentLOS> createLOSCurvedLine(Vector3D center, Vector3D normal,
-                                                       double halfAperture, double sagitta, int n) {
+    private TimeDependentLOS createLOSCurvedLine(Vector3D center, Vector3D normal,
+                                                 double halfAperture, double sagitta, int n) {
         Vector3D u = Vector3D.crossProduct(center, normal);
         List<Vector3D> list = new ArrayList<Vector3D>(n);
         for (int i = 0; i < n; ++i) {
diff --git a/src/main/java/org/orekit/rugged/los/FixedRotation.java b/src/main/java/org/orekit/rugged/los/FixedRotation.java
index 8489e3ba1215abcfb97ed3015926ca7b8d7ef1c4..0e73277e3493b809880e28ada63255c73cf4092a 100644
--- a/src/main/java/org/orekit/rugged/los/FixedRotation.java
+++ b/src/main/java/org/orekit/rugged/los/FixedRotation.java
@@ -18,13 +18,12 @@ package org.orekit.rugged.los;
 
 import org.apache.commons.math3.geometry.euclidean.threed.Rotation;
 import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;
-import org.orekit.time.AbsoluteDate;
 
 /** {@link LOSTransform LOS transform} based on a fixed rotation.
  * @author Luc Maisonobe
  * @see LOSBuilder
  */
-public class FixedRotation implements LOSTransform {
+public class FixedRotation implements TimeIndependentLOSTransform {
 
     /** Underlying rotation. */
     private final Rotation rotation;
@@ -38,7 +37,7 @@ public class FixedRotation implements LOSTransform {
 
     /** {@inheritDoc} */
     @Override
-    public Vector3D transformLOS(final int i, final Vector3D los, final AbsoluteDate date) {
+    public Vector3D transformLOS(final int i, final Vector3D los) {
         return rotation.applyTo(los);
     }
 
@@ -18,13 +18,12 @@ package org.orekit.rugged.los;
 
-/** {@link LOSTransform LOS transform} based on a fixed rotation.
+/** {@link TimeIndependentLOSTransform LOS transform} based on a fixed rotation.
  * @author Luc Maisonobe
  * @see LOSBuilder
diff --git a/src/main/java/org/orekit/rugged/los/FixedLOS.java b/src/main/java/org/orekit/rugged/los/TimeIndependentLOSTransform.java
similarity index 67%
rename from src/main/java/org/orekit/rugged/los/FixedLOS.java
rename to src/main/java/org/orekit/rugged/los/TimeIndependentLOSTransform.java
index ef969099d5a2a3ef85b7a98e1dc87ca64078cf40..c75de032088d1a70830c3d37ac58ccbf515c3445 100644
--- a/src/main/java/org/orekit/rugged/los/FixedLOS.java
+++ b/src/main/java/org/orekit/rugged/los/TimeIndependentLOSTransform.java
@@ -17,27 +17,18 @@
 package org.orekit.rugged.los;
 
 import org.apache.commons.math3.geometry.euclidean.threed.Vector3D;
-import org.orekit.time.AbsoluteDate;
 
-/** Line-of-sight which does not depends on time.
- * @see LineSensor
+/** Interface for lines-of-sight tranforms that do not depend on time.
  * @author Luc Maisonobe
+ * @see LOSBuilder
  */
-class FixedLOS implements TimeDependentLOS {
+interface TimeIndependentLOSTransform {
 
-    /** Fixed direction for los. */
-    private final Vector3D los;
-
-    /** Simple constructor.
-     * @param los fixed direction for the line of sight
+    /** Transform a line-of-sight.
+     * @param i los pixel index
+     * @param los line-of-sight to transform
+     * @return transformed line-of-sight
      */
-    public FixedLOS(final Vector3D los) {
-        this.los = los;
-    }
-
-    /** {@inheritDoc} */
-    public Vector3D getLOS(final AbsoluteDate date) {
-        return los;
-    }
+    Vector3D transformLOS(int i, Vector3D los);
 
 }